from .oxide import weibull_model


__doc__ = oxide.__doc__
if hasattr(oxide, "__all__"):
	__all__ = oxide.__all__
